@@ -19,7 +19,8 @@ package PostScript::File;
 #---------------------------------------------------------------------
 
 use 5.008;
-our $VERSION = '2.00';          ## no critic
+our $VERSION = '2.01';          ## no critic
+# This file is part of PostScript-File 2.01 (March 3, 2010)
 
 use strict;
 use warnings;
@@ -1853,9 +1854,9 @@ PostScript::File - Base class for creating Adobe PostScript files
 
 =head1 VERSION
 
-This document describes version 2.00 of
-PostScript::File, released February 26, 2010
-as part of PostScript-File version 2.00.
+This document describes version 2.01 of
+PostScript::File, released March 3, 2010
+as part of PostScript-File version 2.01.
 
 =head1 SYNOPSIS
 
@@ -3042,7 +3043,7 @@ Any leading '~' is expanded to the users home directory.  If no absolute directo
 C<file>, it is placed within the current directory.  Intervening directories are always created.  If C<create> is
 set, C<file> is created as an empty file, possible erasing any previous file of the same name.
 
-B<File::Spec|File::Spec> is used throughout so file access should be portable.
+L<File::Spec> is used throughout so file access should be portable.
 
 =head2 check_tilde( dir )
 
@@ -3093,15 +3094,15 @@ Most of these functions have only had a couple of tests, so please feel free to
 
 =head1 AUTHOR
 
-Chris Willmot   C<< <chris AT willmot.co.uk> >>
+Chris Willmot   C<< <chrisATwillmot.co.uk> >>
 
 Thanks to Johan Vromans for the ISOLatin1Encoding.
 
 As of September 2009, PostScript::File is now being maintained by
-Christopher J. Madsen  C<< <perl AT cjmweb.net> >>
+Christopher J. Madsen  C<< <perlATcjmweb.net> >>.
 
 Please report any bugs or feature requests to
-S<< C<< <bug-PostScript-File AT rt.cpan.org> >> >>,
+C<< <bug-PostScript-FileATrt.cpan.org> >>,
 or through the web interface at
 L<http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-File>
 
